@@ -6,6 +6,7 @@ import pandas as pd
 import sqlalchemy
 import aiofiles
 import inspect
+import asyncio
 import os
 
 engine_manager = EngineManager()
@@ -149,38 +150,27 @@ async def backup_table(table_to_backup , conn):
             logger.error(f"Failed to create backup: {e}")
             raise
 
-"""Reads an SQL query from a file.
-
-Args:
-    file_path (str): Path to the file containing the SQL query.
-
-Returns:
-    str: The content of the file as a query string.
-
-Raises:
-    FileNotFoundError: If the file does not exist.
-    ValueError: If the file is empty.
-    IOError: If there is an issue reading the file.
-"""
-def get_query_from_file (file_path: str) -> str:
-    """
-    Reads an SQL query from a file.
+""" Reads an SQL query from a file, executes it, and optionally backs up a table.
 
     Args:
         file_path (str): Path to the file containing the SQL query.
+        table_to_backup (str): Name of the table to back up before query execution.
+        env_file_name (str, optional): Path to the environment file for database connection. Defaults to None.
+        params (dict or tuple, optional): Parameters to bind to the SQL query. Defaults to None.
 
     Returns:
-        str: The content of the file as a query string.
+        Any: The result of the executed query.
 
     Raises:
         FileNotFoundError: If the file does not exist.
-        IOError: If there is an issue reading the file.
+        ValueError: If the file is empty.
+        IOError: If there is an issue reading the file or executing the query.
     """
+def get_query_from_file(file_path, table_to_backup, env_file_name=None, params=None):
     if not os.path.exists(file_path):
         error_message = f"File '{file_path}' not found."
         logger.error(error_message)
         raise FileNotFoundError(error_message)
-
     try:
         with open(file_path, "r", encoding="utf-8") as file:
             query = file.read().strip()
@@ -188,12 +178,13 @@ def get_query_from_file (file_path: str) -> str:
                 error_message = f"The file '{file_path}' is empty."
                 logger.error(error_message)
                 raise ValueError(error_message)
-            return query
+            return asyncio.run(get_query_from_db(query, table_to_backup , env_file_name , params))
     except ValueError:  # Handle explicit empty file exception
         raise
     except Exception as e:
-        logger.error(f"Failed to read query from file '{file_path}': {e}")
-        raise IOError(f"Failed to read query from file '{file_path}': {e}")
+        error_message = f"Failed to read query from file '{file_path}': {e}"
+        logger.error(error_message)
+        raise IOError(error_message)
 
 
 
